@@ -62,7 +62,7 @@
   #:use-module ((nyacc lex) #:select (cnumstr->scm))
   #:use-module ((nyacc util) #:select (ugly-print))
   #:re-export (*nyacc-version*)
-  #:version (2 00 5))
+  #:version (2 00 6))
 
 ;; maybe change to a record-type
 (define *options* (make-parameter '()))
@@ -427,17 +427,9 @@
                           (xdecl (expand-typerefs udecl (*udict*) defined))
                           (mdecl (udecl->mdecl xdecl)))
                      (mtail->ctype (md-tail mdecl)))))))
-         ((void) (error "mtail->ctype: arg not expected: void") #f)
+         ((void) (fherr "void not expected") #f)
          ((fixed-type ,name) `(cbase ',(cstrnam->symnam name)))
          ((float-type ,name) `(cbase ',(cstrnam->symnam name)))
-         ((enum-def (@ . ,attr) (ident ,ident) ,rest)
-          (mtail->ctype `((enum-def (@ . ,attr) ,rest))))
-         ((enum-def (@ . ,attr) ,edl)
-          (let ((def-list (canize-enum-def-list edl (*udict*) (*ddict*))))
-            (if (packed? attr)
-                `(cenum ',(enum-def-list->alist def-list) #t)
-                `(cenum ',(enum-def-list->alist def-list)))))
-         ((enum-ref ,name) (strings->symbol "enum-" name))
          ((struct-def (@ . ,attr) (ident ,struct-name) ,field-list)
           (mtail->ctype `((struct-def (@ . ,attr) ,field-list))))
          ((struct-def (@ . ,attr) (field-list . ,fields))
@@ -446,15 +438,22 @@
                 `(cstruct (list ,@fields) #t)
                 `(cstruct (list ,@fields)))))
          ((struct-ref (ident ,struct-name))
-          (string->symbol (string-append "struct-" struct-name)))
+          (strings->symbol "struct-" struct-name))
          ((union-def (ident ,name) ,field-list)
           (mtail->ctype `((union-def ,field-list))))
          ((union-def (field-list . ,fields))
           `(cunion (list ,@(cnvt-fields fields mtail->ctype))))
-         ((union-ref (ident ,name))
-          (strings->symbol "union-" name))
+         ((union-ref (ident ,name)) (strings->symbol "union-" name))
+         ((enum-def (@ . ,attr) (ident ,ident) ,rest)
+          (mtail->ctype `((enum-def (@ . ,attr) ,rest))))
+         ((enum-def (@ . ,attr) ,edl)
+          (let ((def-list (canize-enum-def-list edl (*udict*) (*ddict*))))
+            (if (packed? attr)
+                `(cenum ',(enum-def-list->alist def-list) #t)
+                `(cenum ',(enum-def-list->alist def-list)))))
+         ((enum-ref (ident ,name)) (strings->symbol "enum-" name))
          (,otherwise (fherr "mtail->ctype missed:\n~A" (ppstr mtail))))))))
-
+(export mtail->ctype)
 
 ;; === output ffi-module header ================================================
 
@@ -588,7 +587,7 @@
       (`(void) #f)
       (`(typename ,name)
        (cond
-	((member name def-defined) `(unwrap-number ,name))
+	((member name def-defined) `(unwrap-number ,mname))
 	((member name defined) (defined-type-unwrapper name mname))
 	(else #f)))
       (`(enum-def (ident ,name) ,_)
